"""
    ExplainaBoard

    Backend APIs for ExplainaBoard  # noqa: E501

    The version of the OpenAPI document: 0.2.2
    Contact: explainaboard@gmail.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import explainaboard_api_client
from explainaboard_api_client.model.benchmark_dataset_config import BenchmarkDatasetConfig
from explainaboard_api_client.model.benchmark_metric import BenchmarkMetric
from explainaboard_api_client.model.benchmark_view_config import BenchmarkViewConfig
from explainaboard_api_client.model.paper import Paper
globals()['BenchmarkDatasetConfig'] = BenchmarkDatasetConfig
globals()['BenchmarkMetric'] = BenchmarkMetric
globals()['BenchmarkViewConfig'] = BenchmarkViewConfig
globals()['Paper'] = Paper
from explainaboard_api_client.model.benchmark_config import BenchmarkConfig


class TestBenchmarkConfig(unittest.TestCase):
    """BenchmarkConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testBenchmarkConfig(self):
        """Test BenchmarkConfig"""
        # FIXME: construct object with mandatory attributes with example values
        # model = BenchmarkConfig()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
