"""
    ExplainaBoard

    Backend APIs for ExplainaBoard  # noqa: E501

    The version of the OpenAPI document: 0.2.2
    Contact: explainaboard@gmail.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import explainaboard_api_client
from explainaboard_api_client.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_benchmark_configs_get(self):
        """Test case for benchmark_configs_get

        Returns all benchmark configs matching the specification  # noqa: E501
        """
        pass

    def test_benchmark_get_by_id(self):
        """Test case for benchmark_get_by_id

        Returns benchmark metadata by id  # noqa: E501
        """
        pass

    def test_datasets_get(self):
        """Test case for datasets_get

        Returns a list of datasets  # noqa: E501
        """
        pass

    def test_datasets_get_by_id(self):
        """Test case for datasets_get_by_id

        Returns dataset metadata by id  # noqa: E501
        """
        pass

    def test_info_get(self):
        """Test case for info_get

        information for environment identifier, backend version, login URL, etc. (not intent for public users)  # noqa: E501
        """
        pass

    def test_system_cases_get_by_id(self):
        """Test case for system_cases_get_by_id

        Returns a list of analysis cases of a particular system.  # noqa: E501
        """
        pass

    def test_system_outputs_get_by_id(self):
        """Test case for system_outputs_get_by_id

        Returns a list of outputs of a particular system.  # noqa: E501
        """
        pass

    def test_systems_analyses_post(self):
        """Test case for systems_analyses_post

        Returns analysis result(s) of one or multiple systems  # noqa: E501
        """
        pass

    def test_systems_delete_by_id(self):
        """Test case for systems_delete_by_id

        Deletes a system by id  # noqa: E501
        """
        pass

    def test_systems_get(self):
        """Test case for systems_get

        Returns a list of systems  # noqa: E501
        """
        pass

    def test_systems_get_by_id(self):
        """Test case for systems_get_by_id

        Returns system metadata info by id  # noqa: E501
        """
        pass

    def test_systems_post(self):
        """Test case for systems_post

        Submits a system  # noqa: E501
        """
        pass

    def test_tasks_get(self):
        """Test case for tasks_get

        Returns all task categories and tasks  # noqa: E501
        """
        pass

    def test_user_get(self):
        """Test case for user_get

        get user info  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
