"""
    ExplainaBoard

    Backend APIs for ExplainaBoard  # noqa: E501

    The version of the OpenAPI document: 0.2.2
    Contact: explainaboard@gmail.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import explainaboard_api_client
from explainaboard_api_client.model.system_all_of import SystemAllOf
from explainaboard_api_client.model.system_all_of_dataset import SystemAllOfDataset
from explainaboard_api_client.model.system_info import SystemInfo
from explainaboard_api_client.model.time import Time
globals()['SystemAllOf'] = SystemAllOf
globals()['SystemAllOfDataset'] = SystemAllOfDataset
globals()['SystemInfo'] = SystemInfo
globals()['Time'] = Time
from explainaboard_api_client.model.system import System


class TestSystem(unittest.TestCase):
    """System unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSystem(self):
        """Test System"""
        # FIXME: construct object with mandatory attributes with example values
        # model = System()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
